@@ -30,22 +30,6 @@ impl ActionError {
 	pub fn into_parts(self) -> (ActionErrorType, Option<Box<dyn Error + Send + Sync>>) {
 		(self.kind, self.source)
 	}
-
-	#[inline]
-	pub(super) fn validation(err: ActionValidationError) -> Self {
-		Self {
-			source: Some(Box::new(err)),
-			kind: ActionErrorType::Validation,
-		}
-	}
-
-	#[inline]
-	pub(super) fn run(err: ActionRunError) -> Self {
-		Self {
-			source: Some(Box::new(err)),
-			kind: ActionErrorType::Run,
-		}
-	}
 }
 
 impl Display for ActionError {
@@ -65,6 +49,24 @@ impl Error for ActionError {
 	}
 }
 
+impl From<ActionRunError> for ActionError {
+	fn from(err: ActionRunError) -> Self {
+		Self {
+			source: Some(Box::new(err)),
+			kind: ActionErrorType::Run,
+		}
+	}
+}
+
+impl From<ActionValidationError> for ActionError {
+	fn from(err: ActionValidationError) -> Self {
+		Self {
+			source: Some(Box::new(err)),
+			kind: ActionErrorType::Validation,
+		}
+	}
+}
+
 /// The type of [`ActionError`] that occurred.
 #[derive(Debug)]
 #[allow(missing_copy_implementations)]
