@@ -11,10 +11,6 @@
 #![allow(clippy::module_name_repetitions, clippy::no_effect_underscore_binding)]
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![cfg_attr(docsrs, deny(rustdoc::broken_intra_doc_links))]
-#![cfg_attr(
-	all(nighttime, not(unwrap_unchecked)),
-	feature(result_option_unwrap_unchecked)
-)]
 #![cfg_attr(not(test), warn(clippy::panic_in_result_fn))]
 //! A simple database system that allows the use of multiple different backends.
 
