@@ -1,13 +1,13 @@
 #![allow(clippy::missing_safety_doc)]
 
-#[cfg(not(nighttime))]
+#[cfg(no_unwrap_unchecked)]
 use std::hint::unreachable_unchecked;
 
 pub unsafe trait InnerUnwrap<T> {
 	unsafe fn inner_unwrap(self) -> T;
 }
 
-#[cfg(not(nighttime))]
+#[cfg(no_unwrap_unchecked)]
 unsafe impl<T> InnerUnwrap<T> for Option<T> {
 	#[inline]
 	#[track_caller]
@@ -17,7 +17,7 @@ unsafe impl<T> InnerUnwrap<T> for Option<T> {
 	}
 }
 
-#[cfg(nighttime)]
+#[cfg(not(no_unwrap_unchecked))]
 unsafe impl<T> InnerUnwrap<T> for Option<T> {
 	#[allow(clippy::inline_always)]
 	#[inline(always)]
@@ -27,7 +27,7 @@ unsafe impl<T> InnerUnwrap<T> for Option<T> {
 	}
 }
 
-#[cfg(not(nighttime))]
+#[cfg(no_unwrap_unchecked)]
 unsafe impl<T, E> InnerUnwrap<T> for Result<T, E> {
 	#[inline]
 	#[track_caller]
@@ -41,7 +41,7 @@ unsafe impl<T, E> InnerUnwrap<T> for Result<T, E> {
 	}
 }
 
-#[cfg(nighttime)]
+#[cfg(not(no_unwrap_unchecked))]
 unsafe impl<T, E> InnerUnwrap<T> for Result<T, E> {
 	#[allow(clippy::inline_always)]
 	#[inline(always)]
@@ -61,6 +61,10 @@ pub mod testing {
 		path::{Path, PathBuf},
 	};
 
+	use crate::atomics::Guard;
+
+	pub static TEST_GUARD: Guard = Guard::new();
+
 	#[cfg(feature = "fs")]
 	#[derive(Debug, Clone)]
 	#[repr(transparent)]
